# Gitea
Gitea is a self-hosted git service. It is a great alternative to GitHub or GitLab. It is lightweight and easy to use. It is also easy to deploy and manage while still providing for functionality like SSO and LDAP integration.

Gitea should be configured to not utilize SSH as the job spec does not support it so that SSH is not exposed outside of the home network. If you want to use SSH, you will need to modify the job spec to expose the port and configure the service to use it. You can still run git operations over HTTPS. 

## Nomad Job for Gitea
You will need to modify the job spec items listed under [TODO](./readme.md#TODO) but there are no Gitea specific adjustments needed. If you run it, it will register with consul and be available to Traefik for routing. If the domain name is configured correctly, you should be able to reach the Gitea setup page to make the needed configuration changes. 

## Service Dependencies
- A Valid [Host Volume](../../../host_init/README.md#storage-and-zfs)
- [Postgres](../postgres/readme.md)

## TODO
If you want to deploy this, you will need to verify you have a valid host volume.

| Line | Default | Adjustment |
| --- | --- | --- |
| 17 | `source = "gitea-data"` | Change `gitea-data` to a valid host volume name |
| 66 | `volume = "gitea-data"` | Change `gitea-data` to the host volume defined on line 15 if applicable |

> To make the instance accessible through TRAEFIK you will need to define the domain to listen on by setting the value(s) on lines 2 and 3. 


## Configuring Gitea
There is no need to embed secrets in the nomad job spec. When you first visit the domain name you configured, you will be prompted to configure Gitea. Postgres should be mounted to the container on the standard `5432` port so you can select postgres as the database type and use `127.0.0.1:5432` as the address and input the username, password, and database name you created for Gitea to use.

If you need help making those credentials, take a look at the [postgres readme](../postgres/readme.md#make-a-new-database).

# Adding CI/CD
Gitea has a fork of act runner that can be used to run Github actions. In order to deploy this with Nomad, you will need to leverage Docker in Docker (DinD) with privileged mode enabled in Docker or pay for the bussiness plan of Docker to have better app isolation. The default runner image provided by Gitea was failing to start DinD Daemon so I included a dockerfile that you can use to specify that the container should be ran as the root user. 

1. Build Image
    ```bash
    docker build --network host --platform linux/amd64 -t <your_gitea_domain>/caleb/nomad_act_runner:0.0.1 .
    ```

    > [!NOTE] 
    > You may not need to specify the platform flag. If you use Apple Silicon but deploy to X86, you will need to include the flag.

2. Push Image
    ```bash
    docker push <your_gitea_domain>/caleb/nomad_act_runner:0.0.1
    ```

4. Run the nomad job with the Gitea_Runner_Token
    ```bash
    nomad job run -var "grt=<your_token>" -var "domain=<gitea_domain>" runner.nomad.hcl
    ```

    > [!NOTE] 
    > If you prefer to not use cli variables, you can update the top of the Nomad Job Spec and manually put in the env variables. 

